@@ -11,11 +11,17 @@ class JournalMiddleware(object):
         user = getattr(request, 'user', None)
         ip = request.META.get('REMOTE_ADDR', None)
         def record(tag, template, using=None, **kwargs):
-            django_journal.record(tag, template, using=using, user=user,
-                    ip=ip, **kwargs)
+            if 'user' not in kwargs:
+                kwargs['user'] = user
+            if 'ip' not in kwargs:
+                kwargs['ip'] = ip
+            django_journal.record(tag, template, using=using,**kwargs)
         def error_record(tag, template, using=None, **kwargs):
-            django_journal.error_record(tag, template, using=using,
-                    user=user, ip=ip, **kwargs)
+            if 'user' not in kwargs:
+                kwargs['user'] = user
+            if 'ip' not in kwargs:
+                kwargs['ip'] = ip
+            django_journal.error_record(tag, template, using=using, **kwargs)
         request.record = record
         request.error_record = error_record
         return None
